#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 json
version:              0.10
visibility:           public
id:                   json-0.10-AycMzXTxSjP2VeLyaiH344
key:                  json-0.10-AycMzXTxSjP2VeLyaiH344
license:              BSD-3-Clause
copyright:            (c) 2007-2018 Galois Inc.
maintainer:           Iavor S. Diatchki (iavor.diatchki@gmail.com)
author:               Galois Inc.
synopsis:             Support for serialising Haskell to and from JSON
description:
    JSON (JavaScript Object Notation) is a lightweight data-interchange
    format. It is easy for humans to read and write. It is easy for
    machines to parse and generate.  It is based on a subset of the
    JavaScript Programming Language, Standard ECMA-262 3rd Edition -
    December 1999.

    This library provides a parser and pretty printer for converting
    between Haskell values and JSON.

category:             Web
abi:                  d3da316a2bcd80366fef63c4b5bca1ef
exposed:              True
exposed-modules:
    Text.JSON Text.JSON.Generic Text.JSON.Pretty Text.JSON.ReadP
    Text.JSON.String Text.JSON.Types

import-dirs:          /usr/lib/ghc-9.6.6/site-local/json-0.10
library-dirs:         /usr/lib/ghc-9.6.6/site-local/json-0.10
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/json-0.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-json
hs-libraries:         HSjson-0.10-AycMzXTxSjP2VeLyaiH344
depends:
    array-0.5.6.0 base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    mtl-2.3.1 pretty-1.1.3.6 syb-0.7.3-H7QXegMKksQGc4JgI4csk0
    text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-json/html/json.haddock
haddock-html:         /usr/share/doc/haskell-json/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

